@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
-from message import Message
-from Deadlines import ProcessDeadline, DeadLine, Workdays, Naturaldays
+from __future__ import absolute_import, unicode_literals
+from .message import Message
+from .Deadlines import ProcessDeadline, DeadLine, Workdays, Naturaldays
 from gestionatr.utils import get_rec_attr
 
 
