@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
-from C2 import C2, Cliente, Contacto
-from C1 import DatosAceptacion
-from W1 import LecturaAportada
-from Deadlines import DeadLine, Workdays, Naturaldays
+from __future__ import absolute_import, unicode_literals
+from .C2 import C2, Cliente, Contacto
+from .C1 import DatosAceptacion
+from .W1 import LecturaAportada
+from .Deadlines import DeadLine, Workdays, Naturaldays
 from gestionatr.utils import get_rec_attr
 from gestionatr.defs import SUBTYPES_R101
 
