@@ -3,8 +3,9 @@
 # pylint: disable=E1002
 # pylint: disable=E1101
 # pylint: disable=C0111
-
+from __future__ import absolute_import, unicode_literals
 from libcomxml.core import XmlModel, XmlField
+import six
 
 
 class Cabecera(XmlModel):
@@ -107,11 +108,8 @@ def rep_fecha_sin_hora(fecha):
 
 
 def rep_decimal(n_decimal):
-    try:
-        dec_format = '{0:.' + str(n_decimal) + 'f}'
-        return lambda decimal: dec_format.format(float(decimal))
-    except Exception as e:
-        pass
+    dec_format = '{0:.' + str(n_decimal) + 'f}'
+    return lambda decimal: dec_format.format(decimal)
 
 
 def rep_entera2(decimal):
@@ -130,4 +128,4 @@ def rep_ruedas(n_rodes):
 
 def rep_cut(length):
     # if empty return text to avoid False
-    return lambda text: text and unicode(text)[:length].strip() or text
+    return lambda text: text and six.text_type(text)[:length].strip() or text
